@@ -1,6 +1,5 @@
-use std::sync::atomic::{AtomicUsize, Ordering};
-use std::{cell::RefCell, io};
-use tokio::sync::mpsc::UnboundedSender;
+use async_channel::Sender;
+use std::{cell::RefCell, io, sync::atomic::AtomicUsize, sync::atomic::Ordering};
 
 use super::arbiter::{Arbiter, SystemCommand};
 use super::builder::{Builder, SystemRunner};
@@ -11,7 +10,7 @@ static SYSTEM_COUNT: AtomicUsize = AtomicUsize::new(0);
 #[derive(Clone, Debug)]
 pub struct System {
     id: usize,
-    sys: UnboundedSender<SystemCommand>,
+    sys: Sender<SystemCommand>,
     arbiter: Arbiter,
     stop_on_panic: bool,
 }
@@ -23,7 +22,7 @@ thread_local!(
 impl System {
     /// Constructs new system and sets it as current
     pub(super) fn construct(
-        sys: UnboundedSender<SystemCommand>,
+        sys: Sender<SystemCommand>,
         arbiter: Arbiter,
         stop_on_panic: bool,
     ) -> Self {
@@ -49,7 +48,7 @@ impl System {
     /// Create new system.
     ///
     /// This method panics if it can not create tokio runtime
-    pub fn new<T: Into<String>>(name: T) -> SystemRunner {
+    pub fn new(name: &str) -> SystemRunner {
         Self::build().name(name).finish()
     }
 
@@ -81,10 +80,10 @@ impl System {
 
     /// Stop the system with a particular exit code.
     pub fn stop_with_code(&self, code: i32) {
-        let _ = self.sys.send(SystemCommand::Exit(code));
+        let _ = self.sys.try_send(SystemCommand::Exit(code));
     }
 
-    pub(super) fn sys(&self) -> &UnboundedSender<SystemCommand> {
+    pub(super) fn sys(&self) -> &Sender<SystemCommand> {
         &self.sys
     }
 
@@ -99,13 +98,13 @@ impl System {
         &self.arbiter
     }
 
-    /// This function will start tokio runtime and will finish once the
+    /// This function will start async runtime and will finish once the
     /// `System::stop()` message get called.
-    /// Function `f` get called within tokio runtime context.
+    /// Function `f` get called within async runtime context.
     pub fn run<F>(f: F) -> io::Result<()>
     where
-        F: FnOnce() + 'static,
+        F: FnOnce() -> io::Result<()> + 'static,
     {
-        Builder::new().run(f)
+        Builder::new().finish().run(f)
     }
 }
